@@ -99,7 +99,7 @@ ggplot.train <- function(data = NULL, mapping = NULL, metric = data$metric[1], p
       if(p >= 2) {
         leg_name <- paramData$label[paramData$parameter == dnm[3]]
         out <- out + geom_point(aes_string(color = dnm[3], shape = dnm[3]))
-        out <- out + geom_line(aes_string(color = dnm[3], shape = dnm[3]))
+        out <- out + geom_line(aes_string(color = dnm[3]))
         out <- out + scale_colour_discrete(name = leg_name) +
           scale_shape_discrete(name = leg_name)
       } else out <- out + geom_point() + geom_line()
@@ -115,13 +115,16 @@ ggplot.train <- function(data = NULL, mapping = NULL, metric = data$metric[1], p
   if(plotType == "level") {
     if(p == 1) stop("Two tuning parameters are required for a level plot")
     dnm <- names(dat)
-    if(is.numeric(dat[,2])) dat[,2] <- factor(format(dat[,2]))
-    if(is.numeric(dat[,3])) dat[,3] <- factor(format(dat[,3]))
+    if(is.numeric(dat[,2])) dat[,2] <- factor(format(dat[,2]), levels = format(sort(unique(dat[,2]))))
+    if(is.numeric(dat[,3])) dat[,3] <- factor(format(dat[,3]), levels = format(sort(unique(dat[,3]))))
     if(p > 2 & nameInStrip) {
       strip_vars <- names(dat)[-(1:3)]
       strip_lab <- as.character(subset(data$modelInfo$parameters, parameter %in% strip_vars)$label)
       for(i in seq_along(strip_vars))
-        dat[, strip_vars[i]] <- factor(paste(strip_lab[i], dat[, strip_vars[i]], sep = ": "))
+        dat[, strip_vars[i]] <- factor(
+          paste(strip_lab[i], format(dat[, strip_vars[i]]), sep = ": "),
+          levels = paste(strip_lab[i], format(sort(unique(dat[, strip_vars[i]]))), sep = ": ")
+        )
     }
     ## TODO: use factor(format(x)) to make a solid block of colors?
     out <- ggplot(dat, aes_string(x = dnm[2], y = dnm[3], fill = metric))
@@ -145,22 +148,27 @@ ggplot.train <- function(data = NULL, mapping = NULL, metric = data$metric[1], p
 #' @rdname plot.rfe
 #' @export
 ggplot.rfe <- function(data = NULL, mapping = NULL, metric = data$metric[1],
-                       output = "layered", ..., environment = NULL)
-{
+                       output = "layered", ..., environment = NULL) {
   if(!(output %in% c("data", "layered", "ggplot")))
     stop("'outout' should be either 'data', 'ggplot' or 'layered'")
   resampText <- resampName(data, FALSE)
   resampText <- paste(metric, resampText)
   if(output == "data") return(data$results)
+
+    if(any(names(data$results) == "Num_Resamples")) {
+      data$results <- 
+        subset(data$results, Num_Resamples >= floor(.5 * length(data$control$index)))
+  }
+  
   notBest <- subset(data$results, Variables != data$bestSubset)
   best <- subset(data$results, Variables == data$bestSubset)
-
+  
   out <- ggplot(data$results, aes_string(x = "Variables", y = metric))
   if(output == "ggplot") return(out)
   out <- out + geom_line()
   out <- out + ylab(resampText)
   out <- out + geom_point(data = notBest, aes_string(x = "Variables", y = metric))
-
+  
   out <- out + geom_point(data=best, aes_string(x = "Variables", y = metric),
                           size = 3, colour="blue")
   out
@@ -173,7 +181,7 @@ random_search_plot <- function(x, metric = x$metric[1]) {
   p_names <- as.character(params$parameter)
 
   exclude <- NULL
-  for(i in seq(along = p_names)) {
+  for(i in seq(along.with = p_names)) {
     if(all(is.na(x$results[, p_names[i]])))
       exclude <- c(exclude, i)
   }
