@@ -1,5 +1,5 @@
 subsemble_index <- function(y, J = 2, V = 10){
-  dat <- data.frame(y = y, index = seq(along = y))
+  dat <- data.frame(y = y, index = seq(along.with = y))
   outer_index <- sample(1:J, size = nrow(dat), replace = TRUE)
   outer_splits <- vector(mode = "list", length = J)
   for(i in 1:J) {
@@ -15,7 +15,7 @@ subsemble_index <- function(y, J = 2, V = 10){
   }
   all_index <- lapply(outer_splits, foo, V = V)
   model_index <- holdout_index <- NULL
-  for(i in seq(along = all_index)) {
+  for(i in seq(along.with = all_index)) {
     model_index   <- c(model_index,   all_index[[i]]$model)
     holdout_index <- c(holdout_index, all_index[[i]]$holdout)
   }
@@ -57,7 +57,7 @@ evalSummaryFunction <- function(y, wts = NULL, perf = NULL, ctrl, lev, metric, m
   }
 
   if(ctrl$classProbs) {
-    for(i in seq(along = lev)) testOutput[, lev[i]] <- runif(nrow(testOutput))
+    for(i in seq(along.with = lev)) testOutput[, lev[i]] <- runif(nrow(testOutput))
     testOutput[, lev] <- t(apply(testOutput[, lev], 1, function(x) x/sum(x)))
   } else {
     if(metric == "ROC" & !ctrl$classProbs)
@@ -145,12 +145,12 @@ flatTable <- function(pred, obs)
 {
   cells <- as.vector(table(pred, obs))
   if(length(cells) == 0) cells <- rep(NA, length(levels(obs))^2)
-  names(cells) <- paste(".cell", seq(along= cells), sep = "")
+  names(cells) <- paste(".cell", seq(along.with= cells), sep = "")
   cells
 }
 
 
-prettySeq <- function(x) paste("Resample", gsub(" ", "0", format(seq(along = x))), sep = "")
+prettySeq <- function(x) paste("Resample", gsub(" ", "0", format(seq(along.with = x))), sep = "")
 
 #' @rdname caret-internal
 #' @export
@@ -196,12 +196,12 @@ partRuleSummary <- function(x)
   classPred <- grep("\\)$", conditions, value = TRUE)
   varUsage <- data.frame(Var = predictors,
                          Overall = 0)
-  for(i in seq(along = predictors))
+  for(i in seq(along.with = predictors))
     varUsage$Overall[i] <- sum(grepl(paste("^", predictors[i], sep = ""), conditions))
 
   numClass <- rep(NA, length(classes))
   names(numClass) <- classes
-  for(i in seq(along = classes))
+  for(i in seq(along.with = classes))
     numClass[i] <- sum(grepl(paste(":", classes[i], sep = " "), classPred))
 
   list(varUsage = varUsage,
@@ -222,12 +222,12 @@ ripperRuleSummary <- function(x)
   conditions <- grep("(<=|>=|<|>|=)", rules, value = TRUE)
   varUsage <- data.frame(Var = predictors,
                          Overall = 0)
-  for(i in seq(along = predictors))
+  for(i in seq(along.with = predictors))
     varUsage$Overall[i] <- sum(grepl(paste("\\(", predictors[i], sep = ""), conditions))
 
   numClass <- rep(NA, length(classes))
   names(numClass) <- classes
-  for(i in seq(along = classes))
+  for(i in seq(along.with = classes))
     numClass[i] <- sum(grepl(paste(x$terms[[2]], "=", classes[i], sep = ""), conditions))
 
   list(varUsage = varUsage,
@@ -255,7 +255,7 @@ repList <- function(x, times = 3, addIndex = FALSE)
 {
   out <- vector(mode = "list", length = times)
   out <- lapply(out, function(a, b) b, b = x)
-  if(addIndex) for(i in seq(along = out)) out[[i]]$.index <- i
+  if(addIndex) for(i in seq(along.with = out)) out[[i]]$.index <- i
   out
 }
 
@@ -337,39 +337,42 @@ requireNamespaceQuietStop <- function(package) {
 
 get_resample_perf <- function (x, ...) UseMethod("get_resample_perf")
 
-get_resample_perf.train <- function(x) {
+#' @export
+get_resample_perf.train <- function(x, ...) {
   if(x$control$returnResamp == "none")
     stop("use returnResamp == 'none' in trainControl()", call. = FALSE)
   out <- merge(x$resample, x$bestTune)
   out[, c(x$perfNames, "Resample")]
 }
 
-get_resample_perf.rfe <- function(x) {
+#' @export
+get_resample_perf.rfe <- function(x, ...) {
   if(x$control$returnResamp == "none")
     stop("use returnResamp == 'none' in trainControl()", call. = FALSE)
   out <- subset(x$resample, Variables == x$bestSubset)
   out[, c(x$perfNames, "Resample")]
 }
 
-get_resample_perf.sbf <- function(x) {
+#' @export
+get_resample_perf.sbf <- function(x, ...) {
   if(x$control$returnResamp == "none")
     stop("use returnResamp == 'none' in trainControl()", call. = FALSE)
   x$resample
 }
 
-get_resample_perf.safs <- function(x) {
+#' @export
+get_resample_perf.safs <- function(x, ...) {
   out <- subset(x$external, Iter == x$optIter)
   out[, !(names(out) %in% "Iter")]
 }
 
-get_resample_perf.gafs <- function(x) {
+#' @export
+get_resample_perf.gafs <- function(x, ...) {
   out <- subset(x$external, Iter == x$optIter)
   out[, !(names(out) %in% "Iter")]
 }
 
 
-
-
 #' Sequences of Variables for Tuning
 #'
 #' This function generates a sequence of \code{mtry} values for random forests.
@@ -400,10 +403,10 @@ var_seq <- function(p, classification = FALSE, len = 3) {
   } else {
     if(p <= len)
     {
-      tuneSeq <- floor(seq(2, to = p, length = p))
+      tuneSeq <- floor(seq(2, to = p, length.out = p))
     } else {
-      if(p < 500 ) tuneSeq <- floor(seq(2, to = p, length = len))
-      else tuneSeq <- floor(2^seq(1, to = log(p, base = 2), length = len))
+      if(p < 500 ) tuneSeq <- floor(seq(2, to = p, length.out = len))
+      else tuneSeq <- floor(2^seq(1, to = log(p, base = 2), length.out = len))
     }
   }
   if(any(table(tuneSeq) > 1)) {
@@ -629,14 +632,14 @@ fill_failed_pred <- function(index, lev, submod){
   nPred <- length(index)
   if(!is.null(lev)) {
     predicted <- rep("", nPred)
-    predicted[seq(along = predicted)] <- NA
+    predicted[seq(along.with = predicted)] <- NA
   } else {
     predicted <- rep(NA, nPred)
   }
   if(!is.null(submod)) {
     tmp <- predicted
     predicted <- vector(mode = "list", length = nrow(submod) + 1)
-    for(i in seq(along = predicted)) predicted[[i]] <- tmp
+    for(i in seq(along.with = predicted)) predicted[[i]] <- tmp
     rm(tmp)
   }
   predicted
