@@ -1,8 +1,8 @@
 #' List predictors used in the model
-#' 
+#'
 #' This class uses a model fit to determine which predictors were used in the
 #' final model.
-#' 
+#'
 #' For \code{\link[randomForest]{randomForest}}, \code{\link[party]{cforest}},
 #' \code{\link[party]{ctree}}, \code{\link[rpart]{rpart}},
 #' \code{\link[ipred:bagging]{ipredbagg}}, \code{\link[ipred]{bagging}},
@@ -10,15 +10,15 @@
 #' \code{\link[pamr]{pamr.train}}, \code{\link[superpc]{superpc.train}},
 #' \code{\link{bagEarth}} and \code{\link{bagFDA}}, an attempt was made to
 #' report the predictors that were actually used in the final model.
-#' 
+#'
 #' The \code{predictors} function can be called on the model object (as opposed
 #' to the \code{\link{train}}) object) and the package will try to find the
 #' appropriate coed (if it exists).
-#' 
+#'
 #' In cases where the predictors cannot be determined, \code{NA} is returned.
 #' For example, \code{\link[nnet]{nnet}} may return missing values from
 #' \code{predictors}.
-#' 
+#'
 #' @aliases predictors predictors.formula predictors.terms predictors.train
 #' predictors.default predictors.list predictors.rfe predictors.sbf
 #' @param x a model object, list or terms
@@ -37,8 +37,8 @@ predictors.train <- function(x, ...) {
   } else code <- x$modelInfo
   if(!is.null(code$predictors)){
     checkInstall(code$library)
-    for(i in seq(along = code$library)) 
-      do.call("require", list(package = code$library[i]))
+    for(i in seq(along.with = code$library))
+      do.call("requireNamespaceQuietStop", list(package = code$library[i]))
     out <- code$predictors(x$finalModel, ...)
   } else {
     if(hasTerms(x)) {
@@ -56,8 +56,8 @@ predictors.default <- function(x, ...) {
   if(!is.null(code)) {
     if(!is.null(code$predictors)){
       checkInstall(code$library)
-      for(i in seq(along = code$library)) 
-        do.call("require", list(package = code$library[i]))
+      for(i in seq(along.with = code$library))
+        do.call("requireNamespaceQuietStop", list(package = code$library[i]))
       out <- code$predictors(x, ...)
     } else {
       if(hasTerms(x)) {
@@ -66,7 +66,7 @@ predictors.default <- function(x, ...) {
     }
   } else {
     out <- if(hasTerms(x)) predictors(x$terms) else NA
-  } 
+  }
   out
 }
 
@@ -82,18 +82,18 @@ hasTerms <- function(x)
 ## when a formula might include other terms (such as interactions)
 ## For example:
 ## > x
-## [1] "medv" "crim" "zn"   "age" 
+## [1] "medv" "crim" "zn"   "age"
 ## > y
-## [1] "crim"     "I(age^2)" "zn"   
+## [1] "crim"     "I(age^2)" "zn"
 ## > basicVars(x, y)
 ## [1] "crim" "zn"   "age"
 
 basicVars <- function(x, y)
   {
     hasVar <- rep(NA, length(x))
-    for(i in seq(along = x))
+    for(i in seq(along.with = x))
       hasVar[i] <- length(grep(x[i], y, fixed = TRUE)) > 0
-    x[hasVar] 
+    x[hasVar]
   }
 
 #' @export
